<?php
/*
Plugin Name: Easy Modal Lite
Plugin URI: http://wizardinternetsolutions.com/plugins/easy-modal/
Description: Easy Modal allows you to easily add just about any shortcodes or other content into a modal window. This includes forms such as CF7.
Author: Wizard Internet Solutions
Version: 1.0.2
Author URI: http://wizardinternetsolutions.com
*/
if (is_admin() && ! function_exists( 'get_plugin_data' ) )
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/* Change Begin */
class EasyModalLite {
	var $Plugin = array(
		'name' => 'Easy Modal Lite',
		'slug' => 'easy-modal-lite',
		'short'=> 'EasyModalLite'
	);
	var $api_url = 'http://wizardinternetsolutions.com/api/';
	function __construct()
	{
		$this->Plugin['file'] = __FILE__;
		$this->Plugin['dir'] = PLUGINDIR.'/'. dirname( plugin_basename(__FILE__));
		$this->Plugin['url'] = trailingslashit  (get_bloginfo('wpurl') ).PLUGINDIR.'/'. dirname( plugin_basename(__FILE__) );
		if (is_admin()) {
			$this->Plugin['info'] = get_plugin_data($this->Plugin['file']);
			$this->Plugin['license'] = get_option($this->Plugin['short'].'_License');
			add_action( 'admin_init', array(&$this, '_styles') );
			add_action( 'admin_init', array(&$this, '_scripts') );
			add_action('admin_menu', array(&$this, '_menus') );
			add_filter( 'plugin_action_links', array(&$this, '_actionLinks') , 10, 2 );
            register_activation_hook(__FILE__, array(&$this, '_init'));
            //register_deactivation_hook(__FILE__, array(&$this, 'uninstall'));
			// TinyMCE Admin
            add_filter('mce_buttons_2', array(&$this, '_TinyMCEButtons'), 999);
            add_filter('tiny_mce_before_init', array(&$this, '_TinyMCEInit'));
        } else {
			add_action('wp_print_styles', array(&$this, '_styles') );
			add_action('wp_print_scripts', array(&$this, '_scripts') );
		}
		// Take over the update check
		add_filter('pre_set_site_transient_update_plugins', array(&$this,'CheckForUpdate'));
		// Take over the Plugin info screen
		add_filter('plugins_api', array(&$this,'GetPluginInfo'), 10, 3);
		/// TEMP: Enable update check on every request. Normally you don't need this! This is for testing only!
		//set_site_transient('update_plugins', null);
	}
	function _init()
	{
		global $wp;
		if(!get_option($this->Plugin['short'].'_Version')) $this->resetOptions();
		update_option($this->Plugin['short'].'_Version', $this->Plugin['info']['Version']);
	}
	function resetOptions()
	{
		update_option($this->Plugin['short'].'_Settings', serialize($this->defaultSettings()));
		update_option($this->Plugin['short'].'_ModalList', serialize(array()));
		update_option($this->Plugin['short'].'_ThemeList', serialize(array('1'=>'Black')));
		$theme = $this->defaultThemeSettings();
		$theme['name'] = 'Black';
		update_option($this->Plugin['short'].'_Theme-1', serialize($theme));
	}


	function _styles()
	{
		if (!is_admin()) wp_enqueue_style($this->Plugin['slug'].'-styles', $this->Plugin['url'].'/inc/css/styles.css');
		else wp_enqueue_style($this->Plugin['slug'].'-admin-styles', $this->Plugin['url'].'/inc/css/admin-styles.css');	
	}
	function _scripts()
	{
		if (!is_admin())	{
			wp_enqueue_script($this->Plugin['slug'].'-scripts', $this->Plugin['url'].'/inc/js/easy-modal.js', array('jquery'));
			$modals = $this->enqueue_modals();
			$themes = $this->enqueue_themes();
			$data = array( 'ajaxurl' => $this->Plugin['url'].'/inc/ajax/content.php' , 'modals' => $modals, 'themes' => $themes );
			$params = array(
				'l10n_print_after' => 'easymodal = ' . json_encode($data) . ';'
			);
			wp_localize_script( $this->Plugin['slug'].'-scripts', 'easymodal', $params );
		} else {
			wp_enqueue_script('jquery-colorpicker', $this->Plugin['url'].'/inc/js/colorpicker.js',  array('jquery'));
		}
	}
	function _menus()
	{
		if (function_exists('add_options_page')) {
			add_menu_page( 'Modals', $this->Plugin['name'] , 10, $this->Plugin['slug'], array(&$this, 'printModalEditor'),'',1000);
			add_submenu_page( $this->Plugin['slug'], 'Theme', 'Theme', 10, $this->Plugin['slug'].'-themes', array(&$this, 'printThemeEditor')); 
			add_submenu_page( $this->Plugin['slug'], 'Settings', 'Settings', 10, $this->Plugin['slug'].'-settings', array(&$this, 'printSettingsEditor')); 
		}
	}   
	function _actionLinks( $links, $file )
	{
		if ( $file == plugin_basename( __FILE__ ) ) {
			$posk_links = '<a href="'.get_admin_url().'admin.php?page='.$this->Plugin['slug'].'-settings">'.__('Settings').'</a>';
			array_unshift( $links, $posk_links );
		}
		return $links;
	}
	function _TinyMCEButtons($orig)
	{
		return array_merge($orig, array('styleselect'));
	}
	function _TinyMCEInit($initArray)
	{
		global $wpdb;
		// Default Wordpress classes
		$defaultClasses = array(
			//'eModal Link' => 'eModal-Link'
			//'eModal Image' => 'eModal-Image',
		);
		// Custom classes
		$modals = $this->getModalList();
		$customClasses = array();
		foreach($modals as $key => $modal){
			$customClasses['eModal'.$modal] = 'eModal eModal-'.$key;
		}        
		// Build array
		foreach($defaultClasses as  $name => $css){
			$initArray['theme_advanced_styles'] .= $name.'='.$css.';';
		}
		foreach($customClasses as $name => $css){
			$initArray['theme_advanced_styles'] .= $name.'='.$css.';';
		} 
		$initArray['theme_advanced_styles'] = rtrim($initArray['theme_advanced_styles'], ';'); // Remove final semicolon from list
		return $initArray;
	}


	function printSettingsEditor()
	{
		echo '<div class="wrap">';
			if($_POST){
				$settings = $this->updateSettings( $_POST );
			}else{
				$settings = $this->getSettings();
			}
			?>
			<form method="post" action="admin.php?page=<?php echo $this->Plugin['slug']?>-settings">
				
                    <?php if($settings['license']==''):?>
                    	<div class="error">
                        	<p>If you purchased the Pro version and havent already recieved a key please email us at <a href="mailto:danieliser@wizardinternetsolutions.com">danieliser@wizardinternetsolutions.com</a></p>
                        </div>    
                    <?php endif;?>            
				<div class="postbox full">
					<h3><?php _e('Settings','easy-modal')?></h3>
					<div class="inside">
						<div>
							<label for="license"><h4><?php _e('License Key','easy-modal')?></h4></label>
							<input <?php echo ($settings['license_status']['status']===200?'style="background-color:#0f0;border-color:#090;"':'')?> type="text" id="license" name="license" value="<?php echo($settings['license']!='' ? $settings['license'] : 'free')?>"/><?php echo $settings['license_status']['message']?>
						</div>
						<div class="submit">
							<input type="submit" name="update_settings" class="button-primary" value="<?php _e('Save Settings','easy-modal')?>" />
						</div>
					</div>
				</div>
			</form>
		</div><?php
	}
	function getSettings()
	{
		$settings = get_option($this->Plugin['short'].'_Settings');
		if (!is_array($settings)) {
			$settings = unserialize($settings);
		}
		return $settings;
	}
	function defaultSettings()
	{
		return array(
			'license'	=> '',
			'autoOpen'	=> 'false',
			'autoOpenId' => '',
			'exitOpen' => 'false',
			'exitOpenId' => ''
		);
	}
	function updateSettings( $_POST = NULL )
	{
		global $wp;
		$settings = unserialize(get_option($this->Plugin['short'].'_Settings'));
		if($_POST)
		{
			$_POST = stripslashes_deep($_POST);
			extract($_POST);
			if (isset($license)) {
				$settings['license'] = $license;
				update_option($this->Plugin['short'].'_License', $license);
				$settings['license_status'] = $this->CheckLicense($license);
			}
			if (isset($autoOpen)) {
				$settings['autoOpen'] = $autoOpen;
			}
			if (isset($autoOpenId)) {
				$settings['autoOpenId'] = $autoOpenId;
			}
			if (isset($exitOpen)) {
				$settings['exitOpen'] = $exitOpen;
			}
			if (isset($exitOpenId)) {
				$settings['exitOpenId'] = $exitOpenId;
			}?>
            <div class="updated"><strong><?php _e('Settings Updated','easy-modal')?>.</strong></div><?php
		}
		update_option($this->Plugin['short'].'_Settings', serialize($settings));
		return $settings;
	}

/* Modal Functions */
	function printModalEditor()
	{?>
		<div class="wrap"><?php
			$modal_id = $_GET['modal_id'];
		if($modal_id > 0 && $_GET['action']=='delete'){?>
			<<< - <a href="admin.php?page=<?php echo $this->Plugin['slug']?>">Back to Modals</a><?php
			if(!$_GET['confirm']=='yes'){?>
			<h2>
				<?php _e('Delete Modal','easy-modal')?>
			</h2>
			<p>Are you sure you want to delete this modal?</p>
			<a class="add-new-h2" href="admin.php?page=<?php echo $this->Plugin['slug']?>&modal_id=<?php echo $modal_id?>&action=delete&confirm=yes">Confirm</a>
            <?php } else {
				$this->deleteModal($modal_id);?>
				<p>Modal Deleted</p><?php
			}
		}elseif($modal_id!=NULL){
                if($_POST){
					$settings = $this->updateModalSettings( $modal_id, $_POST );
				}elseif($modal_id=='new'){
					$settings = $this->defaultModalSettings();
				}else{
					$settings = $this->getModalSettings( $modal_id );
				}
				?>
				<<< - <a href="admin.php?page=<?php echo $this->Plugin['slug']?>">Back to Modal Lists</a>
                <h2>
                    <?php echo ucfirst($settings['name']).' '; _e('Modal','easy-modal')?>
                    <a class="add-new-h2" href="admin.php?page=<?php echo $this->Plugin['slug']?>&modal_id=<?php echo $modal_id?>&action=delete">Delete</a>
                </h2>
				<form method="post" action="admin.php?page=<?php echo $this->Plugin['slug']?>&modal_id=<?php echo ($settings['modal_id']!=''?$settings['modal_id']:'new')?>">
					<div class="postbox full">
						<h3><?php _e('Modal','easy-modal')?></h3>
						<div class="inside">
							<label for="name"><h4><?php _e('Classes','easy-modal')?><span class="desc"><?php _e('Copy these to the link/button used to open this modal.','easy-modal')?></span></h4></label>
							<input type="text" value="eModal eModal-<?php echo $settings['modal_id']?>" />
                            
							<label for="name"><h4><?php _e('Name','easy-modal')?><span class="desc"><?php _e('','easy-modal')?></span></h4></label>
							<input type="text" id="name" name="name" value="<?php echo $settings['name'];?>" />
	
							<label for="title"><h4><?php _e('Title','easy-modal')?><span class="desc"><?php _e('The title that appears in the modal window.','easy-modal')?></span></h4></label>
							<input type="text" id="title" name="title" value="<?php echo $settings['title'];?>" />
	
							<label for="content"><h4><?php _e('Content','easy-modal');?><span class="desc"><?php _e('Modal content. Can contain shortcodes.','easy-modal')?></span></h4></label>
							<textarea id="content" name="content" style="width: 100%; height: auto;"><?php echo $settings['content']?></textarea>

							<input type="hidden" name="theme" id="theme" value="1" />
							<div class="submit">
								<input type="submit" name="update_settings" class="button-primary" value="<?php _e('Save Settings','easy-modal')?>" />
							</div>
						</div>
					</div>
				</form><?php
			}
			else
			{
				$modals = $this->getModalList();
				?>
				<h2>Easy Modal Modals<a class="add-new-h2" href="admin.php?page=<?php echo $this->Plugin['slug']?>&modal_id=new">Add New</a></h2>
				<?php if( count($modals) > 0 ){?>
					<table>
						<thead>
							<th>Name</th>
						</thead>
						<tbody><?php
						foreach($modals as $id => $name){
							echo '<tr><td><a href="admin.php?page='. $this->Plugin['slug']. '&modal_id='.$id.'">'.ucfirst($name).'</a></td></tr>';
						}?>
						</tbody>
					</table><?php
				} else { ?>
					<p>To get started click the "add new" button above</p> 
					<?php
				}
			}?>
        </div><?php
	}
	function getModalList()
	{
		$return = get_option($this->Plugin['short'].'_ModalList');
		if(is_array($return)){
			return $return;
		} else {
			return unserialize($return);
		}
	}
	function getModalSettings($modal_id)
	{
		$settings = get_option($this->Plugin['short'].'_Modal-'.$modal_id);
		if (!is_array($settings)) {
			$settings = unserialize($settings);
		}
		return $settings;
	}
	function defaultModalSettings()
	{
		return array(
			'name'	=> 'change_me',
			'title' => '',
			'content' => '',
			'cf7form' => false,
			'theme' => 1
		);
	}
	function updateModalSettings( $modal_id, $_POST = NULL )
	{
		global $wp;
		$modals = unserialize(get_option($this->Plugin['short'].'_ModalList'));
		if($modal_id == 'new')
		{
			$highest = 0;
			foreach($modals as $id => $name)
			{
				if($id > $highest) $highest = $id;
			}
			$modal_id = $highest+1;
		}
		if(array_key_exists($modal_id, $modals))
		{
			$settings = unserialize(get_option( $this->Plugin['short'].'_Modal-'.$modal_id));
		}
		else
		{
			$settings = $this->defaultModalSettings();
		}
		$settings['modal_id'] = $modal_id;
		if($_POST)
		{
			$_POST = stripslashes_deep($_POST);
			extract($_POST);
			if (isset($name)) {
				$settings['name'] = $name;
			}
			if (isset($title)) {
				$settings['title'] = apply_filters('content_save_pre', $title);
			}
			if (isset($content)) {
				if(strstr($content,'[contact-form')!= NULL){ $settings['cf7form'] = true; }
				else { $settings['cf7form'] = false; }
				$settings['content'] = $content;
			}
			if (isset($overlayClose)) {
				$settings['overlayClose'] = $overlayClose;
			}
			if (isset($clickOpen)) {
				$settings['clickOpen'] = $clickOpen;
			}
			if (isset($autoOpen)) {
				$settings['autoOpen'] = $autoOpen;
			}
			if (isset($exitOpen)) {
				$settings['exitOpen'] = $exitOpen;
			}?>
            <div class="updated"><strong><?php _e('Settings Updated','easy-modal')?>.</strong></div><?php
		}
		$modals[$modal_id] = $settings['name'];
		update_option($this->Plugin['short'].'_ModalList', serialize($modals));
		update_option($this->Plugin['short'].'_Modal-'.$modal_id, serialize($settings));
		return $settings;
	}
	function deleteModal( $modal_id )
	{
		$modals = unserialize(get_option($this->Plugin['short'].'_ModalList'));
		unset($modals[$modal_id]);
		update_option($this->Plugin['short'].'_ModalList', serialize($modals));
		delete_option($this->Plugin['short'].'_Modal-'.$modal_id);
	}
	function enqueue_modals()
	{
		$modals = $this->getModalList();
		$settings = array();
		$setting = $this->getModalSettings('Link');
		$settings['Link'] = array(
			"requestData" => array(
				"modalId" => 'Link'
			),
			"theme" => '1',
			"type"	=> 'Link'
		);
		foreach($modals as $key => $value){
			$setting = $this->getModalSettings($key);
			unset($setting['content'],$setting['title']);
			$setting["requestData"] = array('modalId' => $key);
			$settings[$key] = $setting;
		}
		return $settings;
	}


/* Theme Functions */
	function printThemeEditor()
	{
		echo '<div class="wrap">';
		$theme_id = 1;
		if($_POST){
			$settings = $this->updateThemeSettings( $theme_id, $_POST );
		}elseif($theme_id=='new'){
			$settings = $this->defaultThemeSettings();
		}else{
			$settings = $this->getThemeSettings( $theme_id );
		}
		global $wp;
		$borderTypes = array(
			'solid' => 'Solid',
			'dotted' => 'Dotted',
			'double' => 'Double'
		);
		$fontFamilys = array(
			'Sans-Serif'=>'Sans-Serif',
			'Tahoma' => 'Tahoma',
			'Georgia' => 'Georgia',
			'Comic Sans MS' => 'Comic Sans MS',
			'Arial' => 'Arial',
			'Lucida Grande' => 'Lucida Grande',
			'Times New Roman' => 'Times New Roman'
		);
		$closePositions = array(
			'topleft' => 'Top Left',
			'topright' => 'Top Right',
			'bottomleft' => 'Bottom Left',
			'bottomright' => 'Bottom Right'
		);
	?>
	<form method="post" action="admin.php?page=<?php echo $this->Plugin['slug']?>-themes&theme_id=<?php echo $theme_id?>">
	<tr>
		<td colspan="2">
			<h2>
				<?php echo ucfirst($settings['name']).' '; _e('Theme','easy-modal')?>
			</h2>
		</td>
	</tr>
	<tr class="form-field">
		<td colspan="2">
			<div class="emthemes">
				<div id="themeOptions">
					<table>
						<tr><th colspan="2"><h2 style="margin:0;"><?php _e('Theme Options','easy-modal')?></h2></th></tr>
						<tr class="odd">
							<th>
								<label for="theme"><h4><?php _e('Theme Name', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="name" id="name" value="<?php echo $settings['name']?>"/>                      
								<span class="description"><?php //_e('Choose the overlay color.','easy-modal')?></span>
							</td>
						</tr>
					</table>
				</div>
				
				<div id="overlayOptions">
					<table>
						<tr><th colspan="2"><h2 style="margin:0;"><?php _e('Overlay','easy-modal')?></h2></th></tr>
						<tr class="odd">
							<th>
								<label for="overlayColor"><h4><?php _e('Overlay Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="overlayColor" id="overlayColor" value="<?php echo $settings['overlayColor']?>" class="colorSelect" style="background-color:<?php echo $settings['overlayColor']?>" />                      
								<span class="description"><?php //_e('Choose the overlay color.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="overlayOpacity"><h4><?php _e('Opacity', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" id="overlayOpacity" name="overlayOpacity" size="20" value="<?php echo $settings['overlayOpacity']?>"/>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
					</table>
				</div>

				<div id="closeOptions">
					<table>
						<tr><th colspan="2"><h2 style="margin:0;"><?php _e('Close Button','easy-modal')?></h2></th></tr>
						<tr class="odd">
							<th>
								<label for="closeBgColor"><h4><?php _e('Background Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="closeBgColor" id="closeBgColor" value="<?php echo $settings['closeBgColor']?>" class="colorSelect" style="background-color:<?php echo $settings['closeBgColor']?>" />                      
								<span class="description"><?php //_e('The Presenter\'s WordPress User ID'); ?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="closeFontColor"><h4><?php _e('Font Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="closeFontColor" id="closeFontColor" value="<?php echo $settings['closeFontColor']?>" class="colorSelect" style="background-color:<?php echo $settings['closeFontColor']?>" />                      
								<span class="description"><?php //_e('The Presenter\'s WordPress User ID'); ?></span>
							</td>
						</tr>
						<tr class="odd">
							<th>
								<label for="closeFontSize"><h4><?php _e('Font Size', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="closeFontSize" id="closeFontSize" value="<?php echo $settings['closeFontSize']?>" />                      
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="closeBorderRadius"><h4><?php _e('Border Radius', 'easy-modal');?></h4></label>
							</th>                    
							<td>
								<input type="text" id="closeBorderRadius" name="closeBorderRadius" value="<?php echo $settings['closeBorderRadius']?>"/>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr class="odd">
							<th>
								<label for="closeSize"><h4><?php _e('Size', 'easy-modal');?></h4></label>
							</th>                    
							<td>
								<input type="text" id="closeSize" name="closeSize" value="<?php echo $settings['closeSize']?>"/>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="closePosition"><h4><?php _e('Position', 'easy-modal');?></h4></label>
							</th>
							<td>
								<select name="closePosition" id="closePosition"><?php
								foreach($closePositions as $type => $name){
									echo '<option value="'.$type.'"'.($type == $settings['closePosition'] ? 'selected="selected"' : '').'>'.$name.'</option>';
								}?>
								</select>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
					</table>
				</div>
				
				<div id="containerOptions">
					<table>
						<tr><th colspan="2"><h2 style="margin:0;"><?php _e('Container','easy-modal')?></h2></th></tr>
						<tr class="odd">
							<th>
								<label for="containerBgColor"><h4><?php _e('Background Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="containerBgColor" id="containerBgColor" value="<?php echo $settings['containerBgColor']?>" class="colorSelect" style="background-color:<?php echo $settings['containerBgColor']?>" />                      
								<span class="description"><?php //_e('The Presenter\'s WordPress User ID'); ?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="containerPadding"><h4><?php _e('Padding', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" id="containerPadding" name="containerPadding" width="20" value="<?php echo $settings['containerPadding']?>"/>
								<span class="description"><?php //_e('The Presenter\'s WordPress User ID'); ?></span>
							</td>
						</tr>
						<tr class="odd">
							<th>
								<label for="containerBorderColor"><h4><?php _e('Border Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="containerBorderColor" id="containerBorderColor" value="<?php echo $settings['containerBorderColor']?>" class="colorSelect" style="background-color:<?php echo $settings['containerBorderColor']?>" />                      
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="containerBorderStyle"><h4><?php _e('Border Style', 'easy-modal');?></h4></label>
							</th>
							<td>
								<select name="containerBorderStyle" id="containerBorderStyle"><?php
								foreach($borderTypes as $type => $name){
									echo '<option value="'.$type.'"'.($type == $settings['containerBorderStyle'] ? 'selected="selected"' : '').'>'.$name.'</option>';
								}?>
								</select>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr class="odd">
							<th>
								<label for="containerBorderWidth"><h4><?php _e('Border Width', 'easy-modal');?></h4></label>
							</th>     
							<td>
								<input type="text" id="containerBorderWidth" name="containerBorderWidth" value="<?php echo $settings['containerBorderWidth']?>"/>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="containerBorderRadius"><h4><?php _e('Border Radius', 'easy-modal');?></h4></label>
							</th>                    
							<td>
								<input type="text" id="containerBorderRadius" name="containerBorderRadius" value="<?php echo $settings['containerBorderRadius']?>"/>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
					</table>
				</div>
				
				<div id="contentOptions">
					<table>
						<tr><th colspan="2"><h2 style="margin:0;"><?php _e('Content','easy-modal')?></h2></th></tr>
						<tr class="odd">
							<th>
								<label for="contentTitleFontColor"><h4><?php _e('Title Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="contentTitleFontColor" id="contentTitleFontColor" value="<?php echo $settings['contentTitleFontColor']?>" class="colorSelect" style="background-color:<?php echo $settings['contentTitleFontColor']?>" />                      
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="contentTitleFontSize"><h4><?php _e('Title Font Size', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="contentTitleFontSize" id="contentTitleFontSize" value="<?php echo $settings['contentTitleFontSize']?>" />                      
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr class="odd">
							<th>
								<label for="contentTitleFontFamily"><h4><?php _e('Title Font Family', 'easy-modal');?></h4></label>
							</th>
							<td>
								<select name="contentTitleFontFamily" id="contentTitleFontFamily"><?php
								foreach($fontFamilys as $type => $name){
									echo '<option value="'.$type.'"'.($type == $settings['contentTitleFontFamily'] ? 'selected="selected"' : '').'>'.$name.'</option>';
								}?>
								</select>
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="contentFontColor"><h4><?php _e('Font Color', 'easy-modal');?></h4></label>
							</th>
							<td>
								<input type="text" name="contentFontColor" id="contentFontColor" value="<?php echo $settings['contentFontColor']?>" class="colorSelect" style="background-color:<?php echo $settings['contentFontColor']?>" />                      
								<span class="description"><?php //_e('The opacity value for the overlay, from 0 - 100.','easy-modal')?></span>
							</td>
						</tr>
					</table>
				</div>
				<div class="submit">
					<input type="submit" name="update_settings" class="button-primary" value="<?php _e('Save Settings','easy-modal')?>" />
				</div>
			</div>

			<div class="empreview">
				<h2><?php _e('eModal Theme Preview','easy-modal')?></h2>
				<div id="eModal-Preview">
					<div id="eModal-Overlay" style="background-color:<?php echo $settings['overlayColor']?>;opacity:<?php echo intval($settings['overlayOpacity'])/100 ?>;"></div>
					<div id="eModal-Container" style="
						background-color:<?php echo $settings['containerBgColor']?>;
						padding:<?php echo $settings['containerPadding']?>px;
						border:<?php echo $settings['containerBorderColor']?> <?php echo $settings['containerBorderWidth'].'px'?> <?php echo $settings['containerBorderStyle']?>;
						-moz-border-radius:<?php echo $settings['containerBorderRadius']?>px;
						-webkit-border-radius:<?php echo $settings['containerBorderRadius']?>px;
						border-radius:<?php echo $settings['containerBorderRadius']?>px;
						behavior: 'url(<?php echo get_bloginfo('wpurl').'/'.$this->Plugin['dir']?>/themes/PIE.htc)';
						color:<?php echo $settings['contentFontColor']?>;
					">
						<a id="eModal-Close" href="#close" style="
							background-color:<?php echo $settings['closeBgColor']?>;
							color:<?php echo $settings['closeFontColor']?>;
							font-size:<?php echo $settings['closeFontSize']?>px;
							-moz-border-radius:<?php echo $settings['closeBorderRadius']?>px;
							-webkit-border-radius:<?php echo $settings['closeBorderRadius']?>px;
							border-radius:<?php echo $settings['closeBorderRadius']?>px;
							width:<?php echo $settings['closeSize']?>px;
							height:<?php echo $settings['closeSize']?>px;
							line-height:<?php echo $settings['closeSize']?>px;
							<?php
							$size = 0-($settings['closeSize']/2).'px';
							$top = $left = $bottom = $right = 'auto';
							switch($settings['closePosition'])
							{
								case 'topleft': 
									$top = $size; 
									$left = $size; 
									break;
								case 'topright':
									$top = $size; 
									$right = $size; 
									break;
								case 'bottomleft': 
									$left = $size; 
									$bottom = $size;
									break;
								case 'bottomright':
									$right = $size; 
									$bottom = $size;
									break;
							}
							?>
							top: <?php echo $top?>;
							bottom: <?php echo $bottom?>;
							left: <?php echo $left?>;
							right: <?php echo $right?>;
						">X</a>
						<h1 id="eModal-Title" style="
							color:<?php echo $settings['contentTitleFontColor']?>;
							font-family:<?php echo $settings['contentTitleFontFamily']?>;
							font-size:<?php echo $settings['contentTitleFontSize']?>;
						">Title Text</h1>
						<p>Suspendisse ipsum eros, tincidunt sed commodo ut, viverra vitae ipsum. Etiam non porta neque. Pellentesque nulla elit, aliquam in ullamcorper at, bibendum sed eros. Morbi non sapien tellus, ac vestibulum eros. In hac habitasse platea dictumst. Nulla vestibulum, diam vel porttitor placerat, eros tortor ultrices lectus, eget faucibus arcu justo eget massa. Maecenas id tellus vitae justo posuere hendrerit aliquet ut dolor.</p>
					</div>
				</div>
			</div>
		</td>
	</tr>
		<script>
			(function($){
				$(document).ready(function(){
					setTimeout(function(){
						var val = parseInt($('[name=containerBorderRadius]').val())+'px';
						$('#eModal-Container').css({
							"-moz-border-radius":val,
							"-webkit-border-radius":val,
							"border-radius":val,
						});
					},1000);

					$('[name=overlayOpacity]').change(function(){
						var val = parseInt($(this).val())/100;

						$('#eModal-Overlay').css({opacity:val});

					});

					$('[name=containerPadding]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Container').css({padding:val});
					});

					$('[name=containerBorderStyle]').change(function(){
						var val = $(this).val();
						$('#eModal-Container').css({borderStyle:val});
					});

					$('[name=containerBorderWidth]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Container').css({borderWidth:val});
					});

					$('[name=containerBorderRadius]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Container').css({
							"-moz-border-radius":val,
							"-webkit-border-radius":val,
							"border-radius":val,
						});
					});

					$('[name=contentTitleFontSize]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Title').css({fontSize:val});
					});

					$('[name=contentTitleFontFamily]').change(function(){
						var val = $(this).val();
						$('#eModal-Title').css({fontFamily:val});
					});

					$('[name=closeBorderRadius]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Close').css({
							"-moz-border-radius":val,
							"-webkit-border-radius":val,
							"border-radius":val,
						});
					});

					$('[name=closeFontSize]').change(function(){
						var val = parseInt($(this).val())+'px';
						$('#eModal-Close').css({fontSize:val});
					});

					$('[name=closeSize]').change(function(){
						var val = parseInt($(this).val());
						var top,bottom,left,right = 'auto';
						switch($('[name=closePosition]').val())
						{
							case 'topright' : 
								top = -(val/2)+'px';
								right = -(val/2)+'px';
								break;
							case 'topleft' : 
								top = -(val/2)+'px';
								left = -(val/2)+'px';
								break;
							case 'bottomright' : 
								bottom = -(val/2)+'px';
								right = -(val/2)+'px';
								break;
							case 'bottomleft' : 
								bottom = -(val/2)+'px';
								left = -(val/2)+'px';
								break;
						}
						$('#eModal-Close').css({
							width:val+'px',
							height:val+'px',
							lineHeight:val+'px',
							left:left,
							right:right,
							top:top,
							bottom:bottom
						});
					});

					$('[name=closePosition]').change(function(){
						var val = parseInt($('[name=closeSize]').val());
						var top,bottom,left,right = 'auto';
						switch($(this).val())
						{
							case 'topright' : 
								top = -(val/2)+'px';
								right = -(val/2)+'px';
								break;
							case 'topleft' : 
								top = -(val/2)+'px';
								left = -(val/2)+'px';
								break;
							case 'bottomright' : 
								bottom = -(val/2)+'px';
								right = -(val/2)+'px';
								break;
							case 'bottomleft' : 
								bottom = -(val/2)+'px';
								left = -(val/2)+'px';
								break;
						}
						$('#eModal-Close').css({
							left:left,
							right:right,
							top:top,
							bottom:bottom
						});
					});

					$('.colorSelect').each(function(){
						var picker = $(this)
						$(this).ColorPicker({
							color: $(picker).val(),
							onShow: function (colpkr) {
								$(colpkr).fadeIn(500);
								return false;
							},
							onHide: function (colpkr) {
								$(colpkr).fadeOut(500);
								return false;
							},
							onChange: function (hsb, hex, rgb) {
								$(picker).css('backgroundColor', '#' + hex).val('#' + hex);
								switch($(picker).attr('name'))
								{
									case 'overlayColor' : $('#eModal-Overlay').css({backgroundColor:'#' + hex});
										break;
									case 'containerBgColor' : $('#eModal-Container').css({backgroundColor:'#' + hex});
										break;
									case 'containerBorderColor' : $('#eModal-Container').css({borderColor:'#' + hex});
										break;
									case 'contentTitleFontColor' : $('#eModal-Title').css({color:'#' + hex});
										break;
									case 'contentFontColor' : $('#eModal-Container').css({color:'#' + hex});
										break;
									case 'closeBgColor' : $('#eModal-Close').css({backgroundColor:'#' + hex});
										break;
									case 'closeBorderColor' : $('#eModal-Close').css({borderColor:'#' + hex});
										break;
									case 'closeFontColor' : $('#eModal-Close').css({color:'#' + hex});
										break;
								}
							}
						});
					})
				});
			})(jQuery)
		</script><?php
		?>
        </div>
        <?php
	}	
	function getThemeList()
	{
		$return = get_option($this->Plugin['short'].'_ThemeList');
		if(is_array($return)){
			return $return;
		} else {
			return unserialize($return);
		}
	}
	function getThemeSettings($theme_id)
	{
		$settings = get_option($this->Plugin['short'].'_Theme-'.$theme_id);
		if (!is_array($settings)) {
			$settings = unserialize($settings);
		}
		return $settings;
	}
	function defaultThemeSettings()
	{
		return array(
			'name' => 'change_me',
			'overlayColor' => '#000000',
			'overlayOpacity' => '75',
			'containerBgColor' => '#000000',
			'containerPadding' => '10',
			'containerBorderColor' => '#ffffff',
			'containerBorderStyle' => 'solid',
			'containerBorderWidth' => '3',
			'containerBorderRadius' => '20',
			'closeBgColor' => '#000000',
			'closeFontColor' => '#ffffff',
			'closeFontSize' => '15',
			'closeBorderRadius' => '10',
			'closeSize' => '20',
			'closePosition' => 'topright',
			'contentTitleFontColor' => '#ffffff',
			'contentTitleFontSize' => '32',
			'contentTitleFontFamily' => 'Tahoma',
			'contentFontColor' => '#ffffff'
		);
	}
	function updateThemeSettings( $theme_id, $_POST = NULL )
	{
		global $wp;
		$themes = unserialize(get_option($this->Plugin['short'].'_ThemeList'));
		if($theme_id == 'new')
		{
			$highest = 0;
			foreach($themes as $id => $name)
			{
				if($id > $highest) $highest = $id;
			}
			$theme_id = $highest+1;
		}
		if(array_key_exists($theme_id, $themes))
		{
			$settings = unserialize(get_option( $this->Plugin['short'].'_Theme-'.$theme_id));
		}
		else
		{
			$settings = $this->defaultThemeSettings();
		}
		if($_POST)
		{
			$_POST   = stripslashes_deep($_POST);
			extract($_POST);
			if (isset($name)) {
				$settings['name'] = $name;
			}
			if (isset($overlayColor)) {
				//hex color is valid
				if(preg_match('/^#[a-f0-9]{6}$/i', $overlayColor)){
					$settings['overlayColor'] = $overlayColor;
				}
			}
			if (isset($overlayOpacity)) {
				if ($overlayOpacity>= 0 && $overlayOpacity<=100){
					$settings['overlayOpacity'] = $overlayOpacity;
				}
			}
			if (isset($containerBgColor)) {
				//hex color is valid
				if(preg_match('/^#[a-f0-9]{6}$/i', $containerBgColor)){
					$settings['containerBgColor'] = $containerBgColor;
				}
			}
			if (isset($containerPadding)) {
				$settings['containerPadding'] = $containerPadding;
			}
			if (isset($containerBorderColor)) {
				//hex color is valid
				if(preg_match('/^#[a-f0-9]{6}$/i', $containerBorderColor)){
					$settings['containerBorderColor'] = $containerBorderColor;
				}
			}
			if (isset($containerBorderStyle)) {
				$settings['containerBorderStyle'] = $containerBorderStyle;
			}
			if (isset($containerBorderWidth)) {
				$settings['containerBorderWidth'] = $containerBorderWidth;
			}
			if (isset($containerBorderRadius)) {
				$settings['containerBorderRadius'] = $containerBorderRadius;
			}
			if (isset($closeBgColor)) {
				if(preg_match('/^#[a-f0-9]{6}$/i', $closeBgColor)){
					$settings['closeBgColor'] = $closeBgColor;
				}
			}
			if (isset($closeFontColor)) {
				if(preg_match('/^#[a-f0-9]{6}$/i', $closeFontColor)){
					$settings['closeFontColor'] = $closeFontColor;
				}
			}
			if (isset($closeFontSize)) {
				$settings['closeFontSize'] = $closeFontSize;
			}
			if (isset($closeBorderRadius)) {
				$settings['closeBorderRadius'] = $closeBorderRadius;
			}
			if (isset($closeSize)) {
				$settings['closeSize'] = $closeSize;
			}
			if (isset($closePosition)) {
				$settings['closePosition'] = $closePosition;
			}
			if (isset($contentTitleFontColor)) {
				//hex color is valid
				if(preg_match('/^#[a-f0-9]{6}$/i', $contentTitleFontColor)){
					$settings['contentTitleFontColor'] = $contentTitleFontColor;
				}
			}
			if (isset($contentTitleFontSize)) {
				$settings['contentTitleFontSize'] = $contentTitleFontSize;
			}
			if (isset($contentTitleFontFamily)) {
				$settings['contentTitleFontFamily'] = $contentTitleFontFamily;
			}
			if (isset($contentFontColor)) {
				//hex color is valid
				if(preg_match('/^#[a-f0-9]{6}$/i', $contentFontColor)){
					$settings['contentFontColor'] = $contentFontColor;
				}
			}?>
            <div class="updated"><strong><?php _e('Settings Updated','easy-modal')?>.</strong></div><?php
		}
		$themes[$theme_id] = $settings['name'];
		update_option($this->Plugin['short'].'_ThemeList', serialize($themes));
		update_option($this->Plugin['short'].'_Theme-'.$theme_id, serialize($settings));
		return $settings;
	}
	function enqueue_themes()
	{
		$themes = $this->getThemeList();
		$settings = array();
		foreach($themes as $key => $value){
			$setting = $this->getThemeSettings($key);
			$settings[$key] = $setting;
		}
		return $settings;
	}
	
	
	
	function CheckLicense()
	{
		$args = new stdClass;
		$args->slug = $this->Plugin['slug'];
		$args->version = $this->Plugin['info']['Version'];
		$request_string = $this->UpdateRequest('license_check', $args);
		$request = wp_remote_post($this->api_url, $request_string);
		if (is_wp_error($request)) {
			$res = new WP_Error('plugins_api_failed', __('An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>'), $request->get_error_message());
		} else {
			$res = unserialize($request['body']);
			
			if ($res === false)
				$res = new WP_Error('plugins_api_failed', __('An unknown error occurred'), $request['body']);
		}
		return $res;
	}
	function CheckForUpdate($checked_data)
	{
		if (empty($checked_data->checked))
			return $checked_data;
		$request_args = array(
			'slug' => $this->Plugin['slug'],
			'version' => $checked_data->checked[$this->Plugin['slug'] .'/'. $this->Plugin['slug'] .'.php'],
		);
		$request_string = $this->UpdateRequest('basic_check', $request_args);
		// Start checking for an update
		$raw_response = wp_remote_post($this->api_url, $request_string);
		if (!is_wp_error($raw_response) && ($raw_response['response']['code'] == 200))
			$response = unserialize($raw_response['body']);
		if (is_object($response) && !empty($response)) // Feed the update data into WP updater
			$checked_data->response[$this->Plugin['slug'] .'/'. $this->Plugin['slug'] .'.php'] = $response;
		return $checked_data;
	}
	function GetPluginInfo($def, $action, $args)
	{
		if ($args->slug != $this->Plugin['slug'])
			return false;
		// Get the current version
		$plugin_info = get_site_transient('update_plugins');
		$current_version = $plugin_info->checked[$this->Plugin['slug'] .'/'. $this->Plugin['slug'] .'.php'];
		$args->version = $current_version;
		$request_string = $this->UpdateRequest($action, $args);
		$request = wp_remote_post($this->api_url, $request_string);
		if (is_wp_error($request)) {
			$res = new WP_Error('plugins_api_failed', __('An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>'), $request->get_error_message());
		} else {
			$res = unserialize($request['body']);
			if ($res === false)
				$res = new WP_Error('plugins_api_failed', __('An unknown error occurred'), $request['body']);
		}
		return $res;
	}
	function UpdateRequest($action, $args)
	{
		global $wp_version;
		return array(
			'body' => array(
				'action' => $action, 
				'request' => serialize($args),
				'domain'  => get_bloginfo('url'),
				'api_key' => md5(get_bloginfo('url')),
				'license' => get_option($this->Plugin['short'].'_License'),
				'wp_version'=> $wp_version
			),
			'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo('url')
		);	
	}
}
$EasyModalLite = new EasyModalLite;